# Entry

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**shard_id** | **int** |  | [optional] 
**brand** | **str** |  | [optional] 
**category** | [**EntryCategory**](EntryCategory.md) |  | [optional] 
**contents** | **object** | The contents of the entry that is actually indexed - should not be used | [optional] 
**contents_size** | **int** | ContentsSize the total size of the contents | [optional] 
**created** | **datetime** | When it was taken | [optional] 
**cron** | **str** |  | [optional] 
**cron_view** | **bool** |  | [optional] 
**deleted** | **bool** |  | [optional] 
**ending_date** | **datetime** |  | [optional] 
**ending_type** | [**EndingType**](EndingType.md) |  | [optional] 
**entry_task** | [**EntryTask**](EntryTask.md) |  | [optional] 
**error_source** | **str** | Source of the error | [optional] 
**file** | **str** | Filename of associated content | [optional] 
**file_id** | **str** | FileID is the file name when saved in the server | [optional] 
**file_metadata** | [**FileMetadata**](FileMetadata.md) |  | [optional] 
**format** | **str** | Holds information on how content is formatted | [optional] 
**has_role** | **bool** | Internal field to make queries on role faster | [optional] 
**history** | [**list[EntryHistory]**](EntryHistory.md) | Edit history | [optional] 
**human_cron** | [**HumanCron**](HumanCron.md) |  | [optional] 
**id** | **str** |  | [optional] 
**instance** | **str** |  | [optional] 
**investigation_id** | **str** | The id of the investigation it belongs to | [optional] 
**modified** | **datetime** |  | [optional] 
**note** | **bool** | Note | [optional] 
**parent_content** | **object** | ParentEntry content - for reference | [optional] 
**parent_entry_truncated** | **bool** | ParentEntryTruncated - indicates weather entry content was truncated | [optional] 
**parent_id** | **str** | ParentId is the ID of the parent entry | [optional] 
**pinned** | **bool** | Mark entry as pinned &#x3D; evidence | [optional] 
**playbook_id** | **str** | PlaybookID - if the entry is assigned as note to a playbook task, it will hold the playbook | [optional] 
**previous_roles** | **list[str]** | PreviousRoleName - do not change this field manually | [optional] 
**read_only** | **bool** | ReadOnly | [optional] 
**recurrent** | **bool** |  | [optional] 
**reputation_size** | **int** | ReputationSize the total size of the reputation | [optional] 
**reputations** | [**list[EntryReputation]**](EntryReputation.md) | EntryReputations the reputations calculated by regex match | [optional] 
**roles** | **list[str]** | The role assigned to this investigation | [optional] 
**scheduled** | **bool** | is it scheduled | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**start_date** | **datetime** |  | [optional] 
**system** | **str** | The name of the system associated with this entry | [optional] 
**tags** | **list[str]** | Tags | [optional] 
**tags_raw** | **list[str]** | TagsRaw | [optional] 
**task_id** | **str** | TaskID - used if the entry is assigned as note to a playbook task | [optional] 
**times** | **int** |  | [optional] 
**timezone_offset** | **int** |  | [optional] 
**type** | [**EntryType**](EntryType.md) |  | [optional] 
**user** | **str** | The user who created  the entry | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


